@@ -42,8 +42,7 @@ def update_price_on_stripe(plan):
     """
     stripe.Price.modify(
         plan.price_id,
-        unit_amount=int(plan.price * 100),
-        recurring={"interval": plan.recurring_interval})
+        active=plan.published)
 
 
 def get_trial_end(days=3):
@@ -52,5 +51,5 @@ def get_trial_end(days=3):
     :param days: Trial period
     :returns int: Trial end timestamp
     """
-    trial_end = datetime.now() + timedelta(minutes=10)
+    trial_end = datetime.now() + timedelta(days=days)
     return int(trial_end.timestamp())
